@@ -104,6 +104,9 @@ class FireTaskBase(defaultdict, FWSerializable):
     def from_dict(cls, m_dict):
         return cls(m_dict)
 
+    def __repr__(self):
+        return '<{}>:{}'.format(self._fw_name, dict(self))
+
 
 class FWAction(FWSerializable):
     """
@@ -137,10 +140,10 @@ class FWAction(FWSerializable):
         self.stored_data = stored_data if stored_data else {}
         self.exit = exit
         self.update_spec = update_spec if update_spec else {}
-        self.mod_spec = mod_spec if isinstance(mod_spec, list) else [mod_spec]
-        self.additions = additions if isinstance(additions, list) else [
+        self.mod_spec = mod_spec if isinstance(mod_spec, (list, tuple)) else [mod_spec]
+        self.additions = additions if isinstance(additions, (list, tuple)) else [
             additions]
-        self.detours = detours if isinstance(detours, list) else [detours]
+        self.detours = detours if isinstance(detours, (list, tuple)) else [detours]
         self.defuse_children = defuse_children
 
     @recursive_serialize
@@ -198,10 +201,10 @@ class FireWork(FWSerializable):
         :param fw_id: (int) an identification number for this FireWork
         """
 
-        tasks = tasks if isinstance(tasks, list) else [tasks]
+        tasks = tasks if isinstance(tasks, (list, tuple)) else [tasks]
 
         self.tasks = tasks
-        self.spec = spec if spec else {}
+        self.spec = spec.copy() if spec else {}
         self.spec['_tasks'] = [t.to_dict() for t in
                                tasks]  # put tasks in a special location of the spec
 
@@ -521,7 +524,7 @@ class Launch(FWSerializable, object):
         "created_on"
         :return: (datetime)
         """
-        states = states if isinstance(states, list) else [states]
+        states = states if isinstance(states, (list, tuple)) else [states]
         for data in self.state_history:
             if data['state'] in states:
                 if use_update_time:
@@ -543,7 +546,7 @@ class Workflow(FWSerializable):
             super(Workflow.Links, self).__init__(*args, **kwargs)
 
             for k, v in list(self.items()):
-                if not isinstance(v, list):
+                if not isinstance(v, (list, tuple)):
                     self[k] = [v]  # v must be list
                 if not isinstance(k, int):
                     try:
