@@ -406,17 +406,18 @@ class LaunchPad(FWSerializable):
     def archive_wf(self, fw_id):
         # first archive all the launches, so they are not used in duplicate checks
         wf = self.get_wf_by_fw_id(fw_id)
-        fw_ids = [f.fw_id for f in wf.fws]
-        for fw_id in fw_ids:
-            self.rerun_fw(fw_id)
+        if wf.state != 'ARCHIVED':
+            fw_ids = [f.fw_id for f in wf.fws]
+            for fw_id in fw_ids:
+                self.rerun_fw(fw_id)
 
-        # second set the state of all FWs to ARCHIVED
-        wf = self.get_wf_by_fw_id(fw_id)
-        for fw in wf.fws:
-            self.fireworks.find_and_modify({'fw_id': fw.fw_id},
-                                           {'$set': {'state': 'ARCHIVED'}})
+            # second set the state of all FWs to ARCHIVED
+            wf = self.get_wf_by_fw_id(fw_id)
+            for fw in wf.fws:
+                self.fireworks.find_and_modify({'fw_id': fw.fw_id},
+                                               {'$set': {'state': 'ARCHIVED'}})
 
-        self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+            self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
 
     def _restart_ids(self, next_fw_id, next_launch_id):
         """
